svn commit: r256294 - head/sys/net80211

Adrian Chadd adrian at FreeBSD.org
Thu Oct 10 19:56:32 UTC 2013


Author: adrian
Date: Thu Oct 10 19:56:31 2013
New Revision: 256294
URL: http://svnweb.freebsd.org/changeset/base/256294

Log:
  Fix the "am I a net80211 vap" check for bpf listeners.
  
  I changed it to use if_transmit a while ago but apparently with monitor
  mode the if_transmit method is overridden.
  
  This is (mostly) a workaround until a more permanent solution can be
  found.
  
  Submitted by:	Patrick Kelsey <kelsey at ieee.org>
  Approved by:	re@ (gjb)

Modified:
  head/sys/net80211/ieee80211_freebsd.c

Modified: head/sys/net80211/ieee80211_freebsd.c
==============================================================================
--- head/sys/net80211/ieee80211_freebsd.c	Thu Oct 10 19:51:38 2013	(r256293)
+++ head/sys/net80211/ieee80211_freebsd.c	Thu Oct 10 19:56:31 2013	(r256294)
@@ -808,9 +808,9 @@ static eventhandler_tag wlan_ifllevent;
 static void
 bpf_track(void *arg, struct ifnet *ifp, int dlt, int attach)
 {
 	/* NB: identify vap's by if_start */
 	if (dlt == DLT_IEEE802_11_RADIO &&
-	    ifp->if_transmit == ieee80211_vap_transmit) {
+	    ifp->if_init == ieee80211_init) {
 		struct ieee80211vap *vap = ifp->if_softc;
 		/*
 		 * Track bpf radiotap listener state.  We mark the vap
@@ -808,9 +808,9 @@ static eventhandler_tag wlan_ifllevent;
 bpf_track(void *arg, struct ifnet *ifp, int dlt, int attach)
 {
-	/* NB: identify vap's by if_start */
+	/* NB: identify vap's by if_init */
 	if (dlt == DLT_IEEE802_11_RADIO &&


More information about the svn-src-head mailing list